# Tulib
A small Python library with some useful tools.

### Installation
```
pip install tulib
```

### Get started
How to turn a string into a list of words in this lib:

```Python
from Tulib import W2L

# Call the W2L method
result = W2L("Hello there, welcome to Tulib!")
```